String clazzTpl({package}) => """
import 'app_debug_model.dart';
import 'package:xanno/xanno.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:$package/store/app_state.dart';
import 'package:$package/route/main.route.dart';
import 'package:$package/widget/theme_builder.dart';
import 'package:$package/store/user/user_state.dart';
import 'package:$package/store/theme/theme_state.dart';
import 'package:observable_builder/observable_builder.dart';

@GRoute(url: '/appDebug', title: 'AppDebug')
class AppDebugPage extends StatelessWidget {
  final String title;

  const AppDebugPage({Key? key, required this.title}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ThemeBuilder(builder: (context, theme) {
      return ObservableBuilder<UserState>(
          create: observableUser,
          memo: (state) => [state.appDebug],
          builder: (context, state) {
            return Scaffold(
              backgroundColor: theme.body,
              appBar: AppBar(
                brightness: theme.type == ThemeType.light
                    ? Brightness.light
                    : Brightness.dark,
                backgroundColor: theme.body,
                iconTheme: IconThemeData(color: theme.title, opacity: 1),
                title: Text(
                  title,
                  style: TextStyle(color: theme.title),
                ),
              ),
              body: ListView.separated(
                itemCount: state.appDebug!.length,
                separatorBuilder: (BuildContext context, int index) {
                  return Divider(
                    color: Colors.white,
                    height: 1,
                  );
                },
                itemBuilder: (BuildContext context, int index) {
                  AppDebugModel item = state.appDebug![index];
                  return GestureDetector(
                    onTap: () {
                      if (item.key == AppDebugKey.errorLog) {
                        Navigator.pushNamed(
                            context, RouteConstant.AppErrorLogPage);
                      }
                    },
                    child: ListTile(
                      title: Text(item.title),
                      subtitle: Text('\${item.on ? '开启' : '关闭'}功能'),
                      tileColor: Colors.grey[300],
                      trailing: [AppDebugKey.errorLog].contains(item.key)
                          ? Icon(Icons.keyboard_arrow_right, size: 30)
                          : CupertinoSwitch(
                              value: item.on,
                              onChanged: (bool value) {
                                item.on = !item.on;
                                observableUser.notify((state) {
                                  state.updateAppDebug(item);
                                });
                              },
                            ),
                    ),
                  );
                },
              ),
            );
          });
    });
  }
}
""";
